@@ -35,6 +35,7 @@ sub make {
     # @options argvs [String] data  Entire email message
     # @options argvs [Array]  load  User defined MTA module list
     # @options argvs [Array]  order The order of MTA modules
+    # @options argvs [Array]  field Email header names to be captured
     # @options argvs [Code]   hook  Reference to callback method
     # @return        [Hash]         Resolved data structure
     my $class = shift;
@@ -42,7 +43,8 @@ sub make {
     my $email = $argvs->{'data'};
 
     my $methodargv = {};
-    my $hookmethod = $argvs->{'hook'} || undef;
+    my $hookmethod = $argvs->{'hook'}  || undef;
+    my $headerlist = $argvs->{'field'} || [];
     my $processing = {
         'from'   => '',     # From_ line
         'header' => {},     # Email header
@@ -64,9 +66,9 @@ sub make {
     # 2. Convert email headers from text to hash reference
     $TryOnFirst = [];
     $processing->{'from'}   = $aftersplit->{'from'};
-    $processing->{'header'} = __PACKAGE__->headers(\$aftersplit->{'header'});
+    $processing->{'header'} = __PACKAGE__->headers(\$aftersplit->{'header'}, $headerlist);
 
-    # 3. Check headers for detecting MTA/MSP module
+    # 3. Check headers for detecting MTA module
     unless( scalar @$TryOnFirst ) {
         push @$TryOnFirst, @{ __PACKAGE__->makeorder($processing->{'header'}) };
     }
@@ -87,11 +89,11 @@ sub make {
     # 5. Rewrite headers of the original message in the body part
     my $rfc822part = $bouncedata->{'rfc822'} || $aftersplit->{'body'};
     if( ref $rfc822part eq '' ) {
-        # Returned from Sisimai::MTA::* or Sisimai::MSP::* modules
+        # Returned value from Sisimai::Bite::Email::* module
         $processing->{'rfc822'} = __PACKAGE__->takeapart(\$rfc822part);
 
     } else {
-        # Returned from Sisimai::CED::* modules
+        # Returned from Sisimai::Bite::JSON::* modules
         $processing->{'rfc822'} = $rfc822part;
     }
     return $processing;
@@ -198,12 +200,14 @@ sub headers {
     # @return        [Hash]          Structured email header data
     my $class = shift;
     my $heads = shift || return undef;
+    my $field = shift || [];
 
     my $currheader = '';
     my $allheaders = {};
     my $structured = {};
 
     map { $allheaders->{ $_ } = 1 } (@HeaderList, @RFC3834Set, keys %$ExtHeaders);
+    map { $allheaders->{ lc $_ } = 1 } @$field if scalar @$field;
     map { $structured->{ $_ } = undef } @HeaderList;
     map { $structured->{ lc $_ } = [] } keys %$MultiHeads;
 
@@ -213,7 +217,6 @@ sub headers {
             # split the line into a header name and a header content
             my $lhs = $1;
             my $rhs = $2;
-
             $currheader = lc $lhs;
             next unless exists $allheaders->{ $currheader };
 
@@ -251,9 +254,9 @@ sub headers {
 }
 
 sub makeorder {
-    # Check headers for detecting MTA/MSP module and returns the order of modules
+    # Check headers for detecting MTA module and returns the order of modules
     # @param         [Hash] heads   Email header data
-    # @return        [Array]        Order of MTA/MSP modules
+    # @return        [Array]        Order of MTA modules
     my $class = shift;
     my $heads = shift || return [];
     my $order = [];
@@ -360,7 +363,7 @@ sub takeapart {
 }
 
 sub parse {
-    # Parse bounce mail with each MTA/MSP module
+    # Parse bounce mail with each MTA module
     # @param               [Hash] argvs    Processing message entity.
     # @param options argvs [Hash] mail     Email message entity
     # @param options mail  [String] from   From line of mbox
@@ -456,7 +459,7 @@ sub parse {
         # 1. Sisimai::ARF 
         # 2. User-Defined Module
         # 3. MTA Module Candidates to be tried on first
-        # 4. Sisimai::MTA::* and MSP::*
+        # 4. Sisimai::Bite::Email::*
         # 5. Sisimai::RFC3464
         # 6. Sisimai::RFC3834
         #
@@ -484,16 +487,16 @@ sub parse {
         }
 
         DEFAULT_LIST: for my $r ( @$DefaultSet ) {
-            # MTA/MSP modules which does not have MTA specific header and did
-            # not match with any regular expressions of Subject header.
+            # MTA modules which does not have MTA specific header and did not
+            # match with any regular expressions of Subject header.
             next if exists $haveloaded->{ $r };
             $hasscanned = $r->scan($mailheader, $bodystring);
             $haveloaded->{ $r } = 1;
             last(SCANNER) if $hasscanned;
         }
 
-        # When the all of Sisimai::MTA::* modules did not return bounce data,
-        # call Sisimai::RFC3464;
+        # When the all of Sisimai::Bite::Email::* modules did not return bounce
+        # data, call Sisimai::RFC3464;
         require Sisimai::RFC3464;
         $hasscanned = Sisimai::RFC3464->scan($mailheader, $bodystring);
         last(SCANNER) if $hasscanned;
@@ -566,16 +569,34 @@ method like the following codes:
 
     my $cmethod = sub {
         my $argv = shift;
-        my $data = { 'x-mailer' => '' };
+        my $data = {
+            'queue-id' => '',
+            'x-mailer' => '',
+            'precedence' => '',
+        };
 
-        if( $argv->{'message'} =~ m/^X-Mailer:\s*(.+)$/m ) {
-            $data->{'x-mailer'} = $1;
+        # Header part of the bounced mail
+        for my $e ( 'x-mailer', 'precedence' ) {
+            next unless exists $argv->{'headers'}->{ $e };
+            $data->{ $e } = $argv->{'headers'}->{ $e };
+        }
+
+        # Message body of the bounced email
+        if( $argv->{'message'} =~ m/^X-Postfix-Queue-ID:\s*(.+)$/m ) {
+            $data->{'queue-id'} = $1;
         }
 
         return $data;
     };
-    my $message = Sisimai::Message->new('data' => $mailtxt, 'hook' => $cmethod);
+
+    my $message = Sisimai::Message->new(
+        'data' => $mailtxt, 
+        'hook' => $cmethod,
+        'field' => ['X-Mailer', 'Precedence']
+    );
     print $message->catch->{'x-mailer'};    # Apple Mail (2.1283)
+    print $message->catch->{'queue-id'};    # 2DAEB222022E
+    print $message->catch->{'precedence'};  # bulk
 
 =head1 INSTANCE METHODS
 
@@ -619,7 +640,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
